;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "pr-review" "20251016.1540"
  "Review github PR."
  '((emacs         "27.1")
    (magit-section "4.0")
    (magit         "4.0")
    (markdown-mode "2.5")
    (ghub          "3.5"))
  :url "https://github.com/blahgeek/emacs-pr-review"
  :commit "d893429168b87003a99bf567932dce57fdac93fa"
  :revdesc "d893429168b8"
  :keywords '("tools")
  :authors '(("Yikai Zhao" . "yikai@z1k.dev"))
  :maintainers '(("Yikai Zhao" . "yikai@z1k.dev")))
